# AWS Report Generator

A Python library to fetch AWS EC2, S3, and IAM data, generate Excel reports, and upload them to an S3 bucket.

## Installation

```sh
pip3 install 23303395-aws-report-generator